export const YouTubeEmbed = ({ videoId, title }) => {
    return (
        <iframe
            className="w-full aspect-video rounded-md"
            src={`https://www.youtube.com/embed/${videoId}`}
            title={title}
            frameBorder="0"
            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
            allowFullScreen
        />
    );
};